about summary refs log tree commit diff
path: root/Src/utils.c
diff options
context:
space:
mode:
authorTanaka Akira <akr@users.sourceforge.net>1999-05-19 13:10:41 +0000
committerTanaka Akira <akr@users.sourceforge.net>1999-05-19 13:10:41 +0000
commit4fec788fa5f6e7c9723e02e3d0b57068ce9785aa (patch)
tree2b4fd7f79ee29b231c77c9bc0bc67b4eed913bef /Src/utils.c
parentea0ddb0fc6073be3d7d289e59b083f564dbd761f (diff)
downloadzsh-4fec788fa5f6e7c9723e02e3d0b57068ce9785aa.tar.gz
zsh-4fec788fa5f6e7c9723e02e3d0b57068ce9785aa.tar.xz
zsh-4fec788fa5f6e7c9723e02e3d0b57068ce9785aa.zip
Diffstat (limited to 'Src/utils.c')
-rw-r--r--Src/utils.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/Src/utils.c b/Src/utils.c
index faeeb0c58..32588b4c3 100644
--- a/Src/utils.c
+++ b/Src/utils.c
@@ -134,7 +134,7 @@ zerrnam(const char *cmd, const char *fmt, const char *str, int num)
 	    fmt++;
 	}
     if (unset(SHINSTDIN) && lineno)
-	fprintf(stderr, " [%ld]\n", lineno);
+	fprintf(stderr, " [%ld]\n", (long)lineno);
     else
 	putc('\n', stderr);
     fflush(stderr);
@@ -1096,15 +1096,15 @@ skipparens(char inpar, char outpar, char **s)
    return level;
 }
 
 /* Convert string to long.  This function (without the z) *
  * is contained in the ANSI standard C library, but a lot *
  * of them seem to be broken.                             */
 
 /**/
-long
+zlong
 zstrtol(const char *s, char **t, int base)
 {
-    long ret = 0;
+    zlong ret = 0;
     int neg;
 
     while (inblank(*s))
@@ -1096,15 +1096,15 @@ skipparens(char inpar, char outpar, char **s)
 }
 
-/* Convert string to long.  This function (without the z) *
- * is contained in the ANSI standard C library, but a lot *
- * of them seem to be broken.                             */
+/* Convert string to zlong (see zsh.h).  This function (without the z) *
+ * is contained in the ANSI standard C library, but a lot of them seem *
+ * to be broken.                                                       */
 
 /**/